function T = ConstructTranslation(dx, dy, dz)
  % -----------------------------------------------------------------------
  % ConstructTranslation - Construct the transformation matrix that
  %                        translates by dx, dy and dz.
  %
  % Args: dx - scalar giving the x component of the translation
  %       dy - scalar giving the y component of the translation
  %       dz - scalar giving the z component of the translation
  %
  % Rtns: T - the 4 x 4 matrix of the transformation
  % -----------------------------------------------------------------------

  T = [
    1   0   0   dx
    0   1   0   dy
    0   0   1   dz
    0   0   0   1
  ];
end
